Range-v3: ranges::v3::delimited_view< Rng, Val > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

All Classes Files Functions Variables Typedefs Modules Pages
Instances and minimal complete definitions | Public Member Functions | List of all members
ranges::v3::delimited_view< Rng, Val > Struct Template Reference
Views
Inheritance diagram for ranges::v3::delimited_view< Rng, Val >:

## Public Member Functions
| delimited_view (Rng &&rng, Val value)
| value_ (std::move(value))
Public Member Functions inherited from ranges::v3::range_adaptor< delimited_view< Rng, Val >, Rng >
base_range_t & | base ()
base_range_t const & | base () const
constexpr | range_adaptor (Rng &&rng)
Public Member Functions inherited from ranges::v3::range_facade< Derived, Inf >
template<typename D = Derived, requires = ( Same<D, Derived>() )>
detail::facade_iterator_t< D > | begin ()
template<typename D = Derived, requires = ( Same<D, Derived>() )>
detail::facade_iterator_t< D const > | begin () const
template<typename D = Derived, requires = ( Same<D, Derived>() )>
detail::facade_sentinel_t< D > | end ()
template<typename D = Derived, requires = ( Same<D, Derived>() )>
detail::facade_sentinel_t< D const > | end () const
Public Member Functions inherited from ranges::v3::range_interface< Derived, Inf >
template<typename D = Derived, requires = ( Same<D, Derived>() && BoundedRange<D>() && BidirectionalRange<D>() )>
range_reference_t< D > | back ()
| Access the last element in a range:
template<typename D = Derived, requires = ( Same<D, Derived>() && BoundedRange<D const>() && BidirectionalRange<D const>() )>
range_reference_t< D const > | back () const
bool | empty () const
template<typename D = Derived, requires = ( Same<D, Derived>() )>
range_reference_t< D > | front ()
| Access the first element in a range:
template<typename D = Derived, requires = ( Same<D, Derived>() )>
range_reference_t< D const > | front () const
| operator bool () const
template<typename Container , typename D = Derived, typename Alloc = typename Container::allocator_type, requires = ( detail::ConvertibleToContainer<D, Container>() )>
| operator Container ()
| Implicit conversion to something that looks like a container.
template<typename Container , typename D = Derived, typename Alloc = typename Container::allocator_type, requires = ( detail::ConvertibleToContainer<D const, Container>() )>
| operator Container () const
bool | operator! () const
template<typename D = Derived, requires = ( Same<D, Derived>() && RandomAccessRange<D>() )>
auto | operator[] (range_difference_t< D > n) -> decltype(std::declval< D & >().begin()[n])
| Simple indexing:
template<typename D = Derived, requires = ( Same<D, Derived>() && RandomAccessRange<D const>() )>
auto | operator[] (range_difference_t< D > n) const -> decltype(std::declval< D const & >().begin()[n])
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && InputRange<D>() )>
auto | operator[] (detail::slice_bounds< range_difference_t< D >> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
| Python-ic slicing:
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && InputRange<D const>() )>
auto | operator[] (detail::slice_bounds< range_difference_t< D >> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && InputRange<D>() && SizedRange<D>() )>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, detail::from_end_< range_difference_t< D >>> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && InputRange<D const>() && SizedRange<D const>() )>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, detail::from_end_< range_difference_t< D >>> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && (InputRange<D>() && SizedRange<D>()) || ForwardRange<D>() )>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, detail::from_end_< range_difference_t< D >>> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && (InputRange<D const>() && SizedRange<D const>()) || ForwardRange<D const>() )>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, detail::from_end_< range_difference_t< D >>> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && InputRange<D>() )>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, end_fn > offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && InputRange<D const>() )>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, end_fn > offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && ((InputRange<D>() && SizedRange<D>()) || ForwardRange<D>()) )>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, end_fn > offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = ( Same<D, Derived>() && ((InputRange<D const>() && SizedRange<D const>()) || ForwardRange<D const>()) )>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, end_fn > offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, requires = ( Same<D, Derived>() && SizedIteratorRange<range_iterator_t<D>, range_sentinel_t<D>>() )>
range_size_t< D > | size () const
| Access the size of the range, if it can be determined:

## Additional Inherited Members
Protected Member Functions inherited from ranges::v3::range_facade< Derived, Inf >
Derived | begin_cursor () const
Derived & | derived ()
Derived const & | derived () const
default_sentinel | end_cursor () const